@@ -24,9 +24,9 @@ def test_telemetry_server_basic():
     server = TelemetryServer(0.01, 0.10, ("0.0.0.0", 0), 0.25)
     assert server.start()
     assert server.daemons.perform_str_all("start")
-    time.sleep(0.5)
+    time.sleep(1.0)
     server.scale_speed(2.0)
-    time.sleep(0.5)
+    time.sleep(1.0)
     assert server.daemons.perform_str_all("stop")
     assert server.stop()
 
@@ -59,9 +59,16 @@ def test_telemetry_server_get_types():
 async def ws_command(wsock, msg: str, expect: bool) -> Tuple[bool, str]:
     """ Test an individual websocket command. """
 
-    await wsock.send(msg)
-    rsp_data = json.loads(await wsock.recv())
-    return rsp_data["success"] == expect, rsp_data["message"]
+    rsp_data: dict = {"success": False, "message": "send failed"}
+    request_success = False
+    try:
+        await wsock.send(msg)
+        rsp_data = json.loads(await wsock.recv())
+        request_success = True
+    except websockets.exceptions.WebSocketException:
+        pass
+    return ((rsp_data["success"] == expect and request_success),
+            rsp_data["message"])
 
 
 async def ws_command_dict(wsock, msg: dict, expect: bool) -> Tuple[bool, str]:
@@ -77,6 +84,7 @@ def test_telemetry_server_ws_telemetry():
     server = TelemetryServer(0.01, 0.10, None, 0.25,
                              websocket_tlm_address=("0.0.0.0", port))
     with server.booted():
+        time.sleep(0.1)
 
         async def telemetry_test():
             """ Send some commands to the server. """
@@ -89,9 +97,8 @@ def test_telemetry_server_ws_telemetry():
                     result = telem.decode_frame(frame, len(frame),
                                                 telem.app_id)
                     assert result["valid"]
-                await websocket.close()
 
-        for _ in range(3):
+        for _ in range(5):
             asyncio.get_event_loop().run_until_complete(telemetry_test())
 
 
@@ -102,6 +109,7 @@ def test_telemetry_server_ws_commands():
     server = TelemetryServer(0.01, 0.10, None, 0.25,
                              websocket_cmd_address=("0.0.0.0", port))
     with server.booted():
+        time.sleep(0.1)
         fails = 0
 
         async def ws_command_check(wsock, cmd: dict, expect: bool) -> None:
@@ -166,9 +174,8 @@ def test_telemetry_server_ws_commands():
                     data["id"] = int(client)
                     await ws_command_check(websocket, cmd, True)
 
-            await websocket.close()
-
-        asyncio.get_event_loop().run_until_complete(help_test())
+        for _ in range(5):
+            asyncio.get_event_loop().run_until_complete(help_test())
 
     assert fails == 0
 
